@@ -334,62 +334,3 @@ void _as_factor(SEXP vec, const char **levels, const int n_lvls)
     _as_factor_SEXP(vec, lvls);
     UNPROTECT(1);
 }
-
-/*
- * Count the number of lines ('\n') in a file.
- *
- * file: an open file stream at position 0
- *
- */
-static double _count_lines(gzFile file)
-{
-    const int LINEBUF_SIZE = 20001;
-    size_t bytes_read;
-    char *buf = (char *) R_alloc(LINEBUF_SIZE + 1, sizeof(char));
-    double lines = 0;
-
-    while ((bytes_read = gzread(file, buf, LINEBUF_SIZE)) > 0) {
-        char *p = buf;
-        while ((p = memchr(p, '\n', (buf + bytes_read) - p))) {
-            ++p;
-            ++lines;
-        }
-    }
-    return lines;
-}
-
-double _count_lines_sum(SEXP files)
-{
-    SEXP nlines = PROTECT(count_lines(files));
-    int i;
-    double nrec = 0;
-    for (i = 0; i < LENGTH(files); ++i)
-        nrec += REAL(nlines)[i];
-
-    UNPROTECT(1);
-    return nrec;
-}
-
-SEXP count_lines(SEXP files)
-{
-    int i, nfile;
-    const char *filepath;
-    gzFile file;
-    SEXP ans = R_NilValue;
-
-    if (!IS_CHARACTER(files))
-        error("'files' must be character()");
-
-    nfile = LENGTH(files);
-    PROTECT(ans = NEW_NUMERIC(nfile));
-    for (i = 0; i < nfile; ++i) {
-        R_CheckUserInterrupt();
-        filepath = translateChar(STRING_ELT(files, i));
-        file = _fopen(filepath, "rb");
-        REAL(ans)[i] = _count_lines(file);
-        gzclose(file);
-    }
-
-    UNPROTECT(1);
-    return ans;
-}
